@@ -17,12 +17,12 @@ else
 fi
 
 if [ -z "${1}" ]; then
-	tag=$(git tag | grep '^gitolite-gentoo-.*$' | sort -r | head -n 1)
+	tag=$(git tag | grep '^gitolite-gentoo-.*$' | sort -Vr | head -n 1)
 else
 	tag=$1
 fi
 
-for foo in $(find ${dirs} -type f); do
+for foo in $(git ls-files ${dirs} ); do
 	[ "${foo:$((${#foo}-3))}" = ".pm" ] && { perl $perl_opts -c $foo; continue; }
 	[ -n "$(grep -m 1 '^#!/usr/bin/perl' $foo)" ] && { perl $perl_opts -c $foo; continue; }
 done
